pub(super) enum SecretFileError {
File(Error),
Decode(Error),
Encode(Error),
Encryption(Error),
}Expand description
All errors that can occur when interacting with a secret file.
Variants
File(Error)
An error occurred when accessing the file.
Decode(Error)
An error occurred when decoding the content.
Encode(Error)
An error occurred when encoding the content.
Encryption(Error)
An error occurred when encrypting or decrypting the content.