pub(super) struct SecretFile;Expand description
An API to read from or write to a file that encodes its content.
Implementations
Sourceimpl SecretFile
impl SecretFile
Sourcepub(super) async fn read<T: DeserializeOwned>(
path: &Path,
passphrase: &str,
) -> Result<T, SecretFileError>
pub(super) async fn read<T: DeserializeOwned>( path: &Path, passphrase: &str, ) -> Result<T, SecretFileError>
Read a secret from the file at the given path.
async fn read_inner( path: &Path, passphrase: &str, ) -> Result<(StoreCipher, EncryptedValue), SecretFileError>
Sourceasync fn get_or_create_cipher(
path: &Path,
passphrase: &str,
) -> Result<StoreCipher, SecretFileError>
async fn get_or_create_cipher( path: &Path, passphrase: &str, ) -> Result<StoreCipher, SecretFileError>
Get the existing cipher at the given path, or create a new one.